
import string

alphabet = string.ascii_lowercase
numbers = '0123456789'

from .decrypt import *
from .encrypt import *
from .commons import *

__title__ = 'caesarcipher'
__version__ = "0.0.1"
__author__ = 'Artur Marchi Pacagnan'
__license__ = 'MIT'
__copyright__ = 'Copyright 2023 Artur Marchi Pacagnan'



import unittest
from ccipher import encrypt, decrypt, alphabet

class TestCaesarCipher(unittest.TestCase):
    def test_encrypt(self):
        self.assertEqual(encrypt(string=alphabet, key=1), "bcdefghijklmnopqrstuvwxyza")

    def test_decrypt(self):
        self.assertEqual(decrypt(string="xlmw mw e qiwweki xs fi higvctxih", key=4), "this is a message to be decrypted")

if __name__ == '__main__':
    unittest.main()



import encrypt
import decrypt
import file

def main():
    cipherkey = 4
    filename = 'file.txt'

    filecontent = file.readFile(filename=filename)
    
    encrypted = encrypt(filecontent, key=cipherkey)
    
    outputEncryptedFilename = 'encrypted.txt'

    file.writeFile(outputEncryptedFilename, encrypted)

    filecontentencrypted = file.readFile(filename=outputEncryptedFilename)

    decrypted = decrypt(string=filecontentencrypted, key=cipherkey)

    outputDecryptedFilename = 'decrypted.txt'

    file.writeFile(outputDecryptedFilename, decrypted)
        
if __name__ == '__main__':
    main()


from __init__ import alphabet, numbers, commons

def decryptLetter(letter: str, key: int) -> str:
    letterIndex = alphabet.find(letter)

    if (letterIndex < 0):
        return letter
    
    newIndex = (letterIndex - key) % len(alphabet)
    
    return alphabet[newIndex]

def decryptNumber(number: int, key: int) -> str:
    numberIndex = numbers.find(number)

    if (numberIndex < 0):
        return number
    
    newIndex = (numberIndex - key) % len(numbers)
    
    return numbers[newIndex]

def decrypt(string: str, key: int) -> str:
    lowerstring = commons.convertStringToLowerCase(string)

    newString = ''

    for letter in lowerstring:
        if (letter.isnumeric()):
            newString += decryptNumber(number=letter, key=key)
        else:
            newString += decryptLetter(letter=letter, key=key)

    return newString


def readFile(filename: str) -> str:    
    with open(filename, 'r', encoding='utf-8') as f:
        fileContent = f.read()
    
    return fileContent

def writeFile(filename: str, string: str) -> bool:
    try:
        with open(filename, 'w', encoding='utf-8') as f:
            f.write(string)
        
        return True
    except:
        Exception('error to write in file')

        return False